@@ -62,7 +62,7 @@
 // Increment as appropriate every time we release a NEW version.
 #define AUDACITY_VERSION   2
 #define AUDACITY_RELEASE   4
-#define AUDACITY_REVISION  1
+#define AUDACITY_REVISION  2
 #define AUDACITY_MODLEVEL  0
 
 #if defined(IS_BETA)
@@ -147,24 +147,21 @@ class wxWindow;
 #define PLATFORM_MAX_PATH MAX_PATH
 #endif
 
-/* Magic for dynamic library import and export. This is unfortunately
- * compiler-specific because there isn't a standard way to do it. Currently it
- * works with the Visual Studio compiler for windows, and for GCC 4+. Anything
- * else gets all symbols made public, which gets messy */
-/* The Visual Studio implementation */
-#ifdef _MSC_VER
+/* The dynamic library import and export for Microsoft Windows.
+ * Supported by Visual Studio and for GCC 4+ */
+#if defined _WIN32 || (defined __CYGWIN__ && defined __GNUC__)
    #ifndef AUDACITY_DLL_API
       #ifdef BUILDING_AUDACITY
-         #define AUDACITY_DLL_API _declspec(dllexport)
+         #define AUDACITY_DLL_API __declspec(dllexport)
       #else
          #ifdef _DLL
-            #define AUDACITY_DLL_API _declspec(dllimport)
+            #define AUDACITY_DLL_API __declspec(dllimport)
          #else
             #define AUDACITY_DLL_API
          #endif
       #endif
    #endif
-#endif //_MSC_VER
+#endif //_WIN32 || (__CYGWIN__ && __GNUC__)
 
 // Put extra symbol information in the release build, for the purpose of gathering
 // profiling information (as from Windows Process Monitor), when there otherwise
@@ -190,23 +187,6 @@ class wxWindow;
    #endif
 #endif
 
-/* The GCC-win32 implementation */
-// bizzarely, GCC-for-win32 supports Visual Studio style symbol visibility, so
-// we use that if building on Cygwin
-#if defined __CYGWIN__ && defined __GNUC__
-   #ifndef AUDACITY_DLL_API
-      #ifdef BUILDING_AUDACITY
-         #define AUDACITY_DLL_API _declspec(dllexport)
-      #else
-         #ifdef _DLL
-            #define AUDACITY_DLL_API _declspec(dllimport)
-         #else
-            #define AUDACITY_DLL_API
-         #endif
-      #endif
-   #endif
-#endif
-
 // These macros are used widely, so declared here.
 #define QUANTIZED_TIME(time, rate) (floor(((double)(time) * (rate)) + 0.5) / (rate))
 // dB - linear amplitude conversions
