@@ -21,7 +21,6 @@ processing.  See also MacrosWindow and ApplyMacroDialog.
 
 #include <wx/defs.h>
 #include <wx/dir.h>
-#include <wx/filedlg.h>
 #include <wx/textfile.h>
 
 #include "Project.h"
@@ -1098,7 +1097,7 @@ void MacroCommands::MigrateLegacyChains()
          newDir.SetFullName(name);
          const auto newPath = newDir.GetFullPath();
          if (!wxFileExists(newPath))
-            FileNames::CopyFile(file, newPath);
+            FileNames::DoCopyFile(file, newPath);
       }
       done = true;
    }
