@@ -168,7 +168,7 @@ void av_log_wx_callback(void* ptr, int level, const char* fmt, va_list vl);
 //----------------------------------------------------------------------------
 // Get FFmpeg library version
 //----------------------------------------------------------------------------
-wxString GetFFmpegVersion(wxWindow *parent);
+TranslatableString GetFFmpegVersion();
 
 /* from here on in, this stuff only applies when ffmpeg is available */
 #if defined(USE_FFMPEG)
@@ -1040,6 +1040,8 @@ struct streamContext
 using Scs = ArrayOf<std::unique_ptr<streamContext>>;
 using ScsPtr = std::shared_ptr<Scs>;
 
+extern FFmpegLibs *FFmpegLibsInst();
+
 #endif // USE_FFMPEG
 #endif // __AUDACITY_FFMPEG__
 
