@@ -37,7 +37,7 @@ used throughout Audacity into this one place.
 #include "PlatformCompatibility.h"
 #include "wxFileNameWrapper.h"
 #include "widgets/AudacityMessageBox.h"
-#include "../lib-src/FileDialog/FileDialog.h"
+#include "widgets/FileDialog/FileDialog.h"
 
 #if defined(__WXMAC__) || defined(__WXGTK__)
 #include <dlfcn.h>
@@ -145,7 +145,7 @@ wxString FileNames::FormatWildcard( const FileTypes &fileTypes )
    }
 }
 
-bool FileNames::CopyFile(
+bool FileNames::DoCopyFile(
    const FilePath& file1, const FilePath& file2, bool overwrite)
 {
 #ifdef __WXMSW__
