@@ -26,6 +26,8 @@
 #include <wx/intl.h>
 
 #if defined(USE_MIDI)
+#include "../lib-src/header-substitutes/allegro.h"
+
 #include <sstream>
 
 #define ROUND(x) ((int) ((x) + 0.5))
@@ -38,10 +40,12 @@
 
 #include "InconsistencyException.h"
 
+#include "effects/TimeWarper.h"
 #include "tracks/ui/TrackView.h"
 #include "tracks/ui/TrackControls.h"
 
 #include "AllThemeResources.h"
+#include "Theme.h"
 
 #ifdef SONIFY
 #include "../lib-src/portmidi/pm_common/portmidi.h"
