@@ -17,12 +17,9 @@
 
 #include <utility>
 #include "Track.h"
-#include "effects/TimeWarper.h"
 
 #if defined(USE_MIDI)
 
-#include "../lib-src/header-substitutes/allegro.h"
-
 // define this switch to play MIDI during redisplay to sonify run times
 // Note that if SONIFY is defined, the default MIDI device will be opened
 // and may block normal MIDI playback.
@@ -63,6 +60,7 @@ using NoteTrackBase =
 using QuantizedTimeAndBeat = std::pair< double, double >;
 
 class StretchHandle;
+class TimeWarper;
 
 class AUDACITY_DLL_API NoteTrack final
    : public NoteTrackBase
