@@ -24,9 +24,7 @@ Paul Licameli split from AudacityProject.cpp
 #include "widgets/AudacityMessageBox.h"
 #include "widgets/NumericTextCtrl.h"
 
-#if defined(__WXMAC__)
-#include "menus/WindowMenus.h"
-#endif
+wxDEFINE_EVENT(EVT_PROJECT_TITLE_CHANGE, wxCommandEvent);
 
 static void RefreshAllTitles(bool bShowProjectNumbers )
 {
@@ -134,13 +132,13 @@ void ProjectFileIO::SetProjectTitle( int number)
       name += _("(Recovered)");
    }
 
-   window.SetTitle( name );
-   window.SetName(name);       // to make the nvda screen reader read the correct title
+   if ( name != window.GetTitle() ) {
+      window.SetTitle( name );
+      window.SetName(name);       // to make the nvda screen reader read the correct title
 
-#if defined(__WXMAC__)
-   // Refresh the Window menu
-   WindowActions::Refresh();
-#endif
+      project.QueueEvent(
+         safenew wxCommandEvent{ EVT_PROJECT_TITLE_CHANGE } );
+   }
 }
 
 // Most of this string was duplicated 3 places. Made the warning consistent in this global.
@@ -179,7 +177,7 @@ bool ProjectFileIO::HandleXMLTag(const wxChar *tag, const wxChar **attrs)
    auto &dirManager = DirManager::Get( project );
    auto &settings = ProjectSettings::Get( project );
    bool bFileVersionFound = false;
-   wxString fileVersion = _("<unrecognized version -- possibly corrupt project file>");
+   wxString fileVersion;
    wxString audacityVersion = _("<unrecognized version -- possibly corrupt project file>");
    int requiredTags = 0;
    long longVpos = 0;
