@@ -59,6 +59,7 @@ is time to refresh some aspect of the screen.
 #include "ProjectSettings.h"
 #include "ProjectStatus.h"
 #include "ProjectWindow.h"
+#include "Theme.h"
 #include "TrackPanelMouseEvent.h"
 #include "TrackPanelResizeHandle.h"
 //#define DEBUG_DRAW_TIMING 1
@@ -698,6 +699,9 @@ void TrackPanel::OnTrackListResizing(TrackListEvent & e)
    if( t && t->HasOwner() )
       UpdateVRuler(t.get());
    e.Skip();
+
+   // fix for bug 2477
+   mListener->TP_RedrawScrollbars();
 }
 
 // Tracks have been removed from the list.
@@ -1549,88 +1553,6 @@ void TrackPanel::OnTrackFocusChange( wxCommandEvent &event )
    }
 }
 
-TrackPanelDrawable::~TrackPanelDrawable()
-{
-}
-
-void TrackPanelDrawable::Draw(
-   TrackPanelDrawingContext &, const wxRect &, unsigned )
-{
-}
-
-wxRect TrackPanelDrawable::DrawingArea(
-   TrackPanelDrawingContext &,
-   const wxRect &rect, const wxRect &, unsigned )
-{
-   return rect;
-}
-
-TrackPanelNode::TrackPanelNode()
-{
-}
-
-TrackPanelNode::~TrackPanelNode()
-{
-}
-
-TrackPanelGroup::TrackPanelGroup()
-{
-}
-
-TrackPanelGroup::~TrackPanelGroup()
-{
-}
-
-TrackPanelCell::~TrackPanelCell()
-{
-}
-
-HitTestPreview TrackPanelCell::DefaultPreview
-(const TrackPanelMouseState &, const AudacityProject *)
-{
-   return {};
-}
-
-unsigned TrackPanelCell::HandleWheelRotation
-(const TrackPanelMouseEvent &, AudacityProject *)
-{
-   return RefreshCode::Cancelled;
-}
-
-unsigned TrackPanelCell::DoContextMenu
-   (const wxRect &, wxWindow*, wxPoint *, AudacityProject*)
-{
-   return RefreshCode::RefreshNone;
-}
-
-unsigned TrackPanelCell::CaptureKey(
-   wxKeyEvent &event, ViewInfo &, wxWindow *, AudacityProject *)
-{
-   event.Skip();
-   return RefreshCode::RefreshNone;
-}
-
-unsigned TrackPanelCell::KeyDown(
-   wxKeyEvent &event, ViewInfo &, wxWindow *, AudacityProject *)
-{
-   event.Skip();
-   return RefreshCode::RefreshNone;
-}
-
-unsigned TrackPanelCell::KeyUp(
-   wxKeyEvent &event, ViewInfo &, wxWindow *, AudacityProject *)
-{
-   event.Skip();
-   return RefreshCode::RefreshNone;
-}
-
-unsigned TrackPanelCell::Char(
-   wxKeyEvent &event, ViewInfo &, wxWindow *, AudacityProject *)
-{
-   event.Skip();
-   return RefreshCode::RefreshNone;
-}
-
 IsVisibleTrack::IsVisibleTrack(AudacityProject *project)
    : mPanelRect {
         wxPoint{ 0, ViewInfo::Get( *project ).vpos },
