@@ -37,7 +37,7 @@ void MessageCommand::PopulateOrExchange(ShuttleGui & S)
 
    S.StartMultiColumn(2, wxALIGN_CENTER);
    {
-      S.TieTextBox(XO("Text:"),mMessage,60);
+      S.TieTextBox(XXO("Text:"),mMessage,60);
    }
    S.EndMultiColumn();
 }
