@@ -50,9 +50,9 @@ void SetEnvelopeCommand::PopulateOrExchange(ShuttleGui & S)
 
    S.StartMultiColumn(3, wxALIGN_CENTER);
    {
-      S.Optional( bHasT           ).TieNumericTextBox(  XO("Time:"),          mT );
-      S.Optional( bHasV           ).TieNumericTextBox(  XO("Value:"),         mV );
-      S.Optional( bHasDelete      ).TieCheckBox(        XO("Delete"),         mbDelete );
+      S.Optional( bHasT           ).TieNumericTextBox(  XXO("Time:"),          mT );
+      S.Optional( bHasV           ).TieNumericTextBox(  XXO("Value:"),         mV );
+      S.Optional( bHasDelete      ).TieCheckBox(        XXO("Delete"),         mbDelete );
    }
    S.EndMultiColumn();
 }
