@@ -53,15 +53,15 @@ void SetLabelCommand::PopulateOrExchange(ShuttleGui & S)
 
    S.StartMultiColumn(2, wxALIGN_CENTER);
    {
-      S.TieNumericTextBox( XO("Label Index"), mLabelIndex );
+      S.TieNumericTextBox( XXO("Label Index"), mLabelIndex );
    }
    S.EndMultiColumn();
    S.StartMultiColumn(3, wxALIGN_CENTER);
    {
-      S.Optional( bHasText      ).TieTextBox(         XO("Text:"),     mText );
-      S.Optional( bHasT0        ).TieNumericTextBox(  XO("Start:"),    mT0 );
-      S.Optional( bHasT1        ).TieNumericTextBox(  XO("End:"),      mT1 );
-      S.Optional( bHasSelected  ).TieCheckBox(        XO("Selected"),  mbSelected );
+      S.Optional( bHasText      ).TieTextBox(         XXO("Text:"),     mText );
+      S.Optional( bHasT0        ).TieNumericTextBox(  XXO("Start:"),    mT0 );
+      S.Optional( bHasT1        ).TieNumericTextBox(  XXO("End:"),      mT1 );
+      S.Optional( bHasSelected  ).TieCheckBox(        XXO("Selected"),  mbSelected );
    }
    S.EndMultiColumn();
 }
