@@ -245,7 +245,7 @@ void EffectAmplify::PopulateOrExchange(ShuttleGui & S)
             .Validator<FloatingPointValidator<double>>(
                precision, &mAmp, NumValidatorStyle::ONE_TRAILING_ZERO, MIN_Amp, MAX_Amp
             )
-            .AddTextBox(XO("&Amplification (dB):"), wxT(""), 12);
+            .AddTextBox(XXO("&Amplification (dB):"), wxT(""), 12);
       }
       S.EndMultiColumn();
 
@@ -272,7 +272,7 @@ void EffectAmplify::PopulateOrExchange(ShuttleGui & S)
                RoundValue( precision + 1, MIN_Amp + LINEAR_TO_DB(mPeak) ),
                RoundValue( precision + 1, MAX_Amp + LINEAR_TO_DB(mPeak) )
             )
-            .AddTextBox(XO("&New Peak Amplitude (dB):"), wxT(""), 12);
+            .AddTextBox(XXO("&New Peak Amplitude (dB):"), wxT(""), 12);
       }
       S.EndMultiColumn();
 
@@ -281,7 +281,7 @@ void EffectAmplify::PopulateOrExchange(ShuttleGui & S)
       {
 
          mClip = S.Id(ID_Clip).Disable( batch )
-            .AddCheckBox(XO("Allo&w clipping"), false);
+            .AddCheckBox(XXO("Allo&w clipping"), false);
       }
       S.EndHorizontalLay();
    }
