@@ -96,7 +96,7 @@ public:
    CommandID GetCommandIdentifier(const PluginID & ID);
    TranslatableString GetCommandDescription(const PluginID & ID);
    wxString GetCommandUrl(const PluginID & ID);
-   wxString GetCommandTip(const PluginID & ID);
+   TranslatableString GetCommandTip(const PluginID & ID);
    // flags control which commands are included.
    void GetCommandDefinition(const PluginID & ID, const CommandContext & context, int flags);
    bool IsHidden(const PluginID & ID);
