@@ -265,7 +265,7 @@ void EffectPhaser::PopulateOrExchange(ShuttleGui & S)
       mStagesT = S.Id(ID_Stages)
          .Validator<IntegerValidator<int>>(
             &mStages, NumValidatorStyle::DEFAULT, MIN_Stages, MAX_Stages)
-         .AddTextBox(XO("&Stages:"), wxT(""), 15);
+         .AddTextBox(XXO("&Stages:"), wxT(""), 15);
 
       mStagesS = S.Id(ID_Stages)
          .Name(XO("Stages"))
@@ -277,7 +277,7 @@ void EffectPhaser::PopulateOrExchange(ShuttleGui & S)
       mDryWetT = S.Id(ID_DryWet)
          .Validator<IntegerValidator<int>>(
             &mDryWet, NumValidatorStyle::DEFAULT, MIN_DryWet, MAX_DryWet)
-         .AddTextBox(XO("&Dry/Wet:"), wxT(""), 15);
+         .AddTextBox(XXO("&Dry/Wet:"), wxT(""), 15);
 
       mDryWetS = S.Id(ID_DryWet)
          .Name(XO("Dry Wet"))
@@ -288,7 +288,7 @@ void EffectPhaser::PopulateOrExchange(ShuttleGui & S)
       mFreqT = S.Id(ID_Freq)
          .Validator<FloatingPointValidator<double>>(
             5, &mFreq, NumValidatorStyle::ONE_TRAILING_ZERO, MIN_Freq, MAX_Freq)
-         .AddTextBox(XO("LFO Freq&uency (Hz):"), wxT(""), 15);
+         .AddTextBox(XXO("LFO Freq&uency (Hz):"), wxT(""), 15);
 
       mFreqS = S.Id(ID_Freq)
          .Name(XO("LFO frequency in hertz"))
@@ -299,7 +299,7 @@ void EffectPhaser::PopulateOrExchange(ShuttleGui & S)
       mPhaseT = S.Id(ID_Phase)
          .Validator<FloatingPointValidator<double>>(
             1, &mPhase, NumValidatorStyle::DEFAULT, MIN_Phase, MAX_Phase)
-         .AddTextBox(XO("LFO Sta&rt Phase (deg.):"), wxT(""), 15);
+         .AddTextBox(XXO("LFO Sta&rt Phase (deg.):"), wxT(""), 15);
 
       mPhaseS = S.Id(ID_Phase)
          .Name(XO("LFO start phase in degrees"))
@@ -311,7 +311,7 @@ void EffectPhaser::PopulateOrExchange(ShuttleGui & S)
       mDepthT = S.Id(ID_Depth)
          .Validator<IntegerValidator<int>>(
             &mDepth, NumValidatorStyle::DEFAULT, MIN_Depth, MAX_Depth)
-         .AddTextBox(XO("Dept&h:"), wxT(""), 15);
+         .AddTextBox(XXO("Dept&h:"), wxT(""), 15);
 
       mDepthS = S.Id(ID_Depth)
          .Name(XO("Depth in percent"))
@@ -322,7 +322,7 @@ void EffectPhaser::PopulateOrExchange(ShuttleGui & S)
       mFeedbackT = S.Id(ID_Feedback)
          .Validator<IntegerValidator<int>>(
             &mFeedback, NumValidatorStyle::DEFAULT, MIN_Feedback, MAX_Feedback)
-         .AddTextBox(XO("Feedbac&k (%):"), wxT(""), 15);
+         .AddTextBox(XXO("Feedbac&k (%):"), wxT(""), 15);
 
       mFeedbackS = S.Id(ID_Feedback)
          .Name(XO("Feedback in percent"))
@@ -334,7 +334,7 @@ void EffectPhaser::PopulateOrExchange(ShuttleGui & S)
       mOutGainT = S.Id(ID_OutGain)
          .Validator<FloatingPointValidator<double>>(
             1, &mOutGain, NumValidatorStyle::DEFAULT, MIN_OutGain, MAX_OutGain)
-         .AddTextBox(XO("&Output gain (dB):"), wxT(""), 12);
+         .AddTextBox(XXO("&Output gain (dB):"), wxT(""), 12);
 
       mOutGainS = S.Id(ID_OutGain)
          .Name(XO("Output gain (dB)"))
