@@ -59,6 +59,7 @@ a graph for EffectScienFilter.
 #include "../Project.h"
 #include "../Shuttle.h"
 #include "../ShuttleGui.h"
+#include "../Theme.h"
 #include "../WaveTrack.h"
 #include "../widgets/valnum.h"
 #include "../widgets/AudacityMessageBox.h"
@@ -473,7 +474,7 @@ void EffectScienFilter::PopulateOrExchange(ShuttleGui & S)
             .Focus()
             .Validator<wxGenericValidator>(&mFilterType)
             .MinSize( { -1, -1 } )
-            .AddChoice(XO("&Filter Type:"),
+            .AddChoice(XXO("&Filter Type:"),
                Msgids(kTypeStrings, nTypes)
             );
 
@@ -481,7 +482,7 @@ void EffectScienFilter::PopulateOrExchange(ShuttleGui & S)
             .Validator<wxGenericValidator>(&mOrderIndex)
             .MinSize( { -1, -1 } )
             /*i18n-hint: 'Order' means the complexity of the filter, and is a number between 1 and 10.*/
-            .AddChoice(XO("O&rder:"),
+            .AddChoice(XXO("O&rder:"),
                []{
                   TranslatableStrings orders;
                   for (int i = 1; i <= 10; i++)
@@ -505,7 +506,7 @@ void EffectScienFilter::PopulateOrExchange(ShuttleGui & S)
          mFilterSubTypeCtl = S.Id(ID_SubType)
             .Validator<wxGenericValidator>(&mFilterSubtype)
             .MinSize( { -1, -1 } )
-            .AddChoice(XO("&Subtype:"),
+            .AddChoice(XXO("&Subtype:"),
                Msgids(kSubTypeStrings, nSubTypes)
             );
 
@@ -514,7 +515,7 @@ void EffectScienFilter::PopulateOrExchange(ShuttleGui & S)
             .Validator<FloatingPointValidator<float>>(
                1, &mCutoff, NumValidatorStyle::DEFAULT,
                MIN_Cutoff, mNyquist - 1)
-            .AddTextBox(XO("C&utoff:"), wxT(""), 10);
+            .AddTextBox(XXO("C&utoff:"), wxT(""), 10);
          S.AddUnits(XO("Hz"));
 
          mStopbandRippleCtlP =
