@@ -265,7 +265,7 @@ void EffectTimeScale::PopulateOrExchange(ShuttleGui & S)
                   NumValidatorStyle::NO_TRAILING_ZEROES,
                   MIN_HalfStepsStart, MAX_HalfStepsStart
                )
-               .AddTextBox(XO("(&semitones) [-12 to 12]:"), wxT(""), 12);
+               .AddTextBox(XXO("(&semitones) [-12 to 12]:"), wxT(""), 12);
 
 
             m_pTextCtrl_PitchPercentChangeStart = S.Id(ID_PitchPercentChangeStart)
@@ -274,7 +274,7 @@ void EffectTimeScale::PopulateOrExchange(ShuttleGui & S)
                   NumValidatorStyle::NO_TRAILING_ZEROES,
                   MIN_PitchPercentStart, MAX_PitchPercentStart
                )
-               .AddTextBox(XO("(%) [-50 to 100]:"), wxT(""), 12);
+               .AddTextBox(XXO("(%) [-50 to 100]:"), wxT(""), 12);
          }
          S.EndMultiColumn();
       }
@@ -291,14 +291,14 @@ void EffectTimeScale::PopulateOrExchange(ShuttleGui & S)
                   NumValidatorStyle::NO_TRAILING_ZEROES,
                   MIN_HalfStepsEnd, MAX_HalfStepsEnd
                )
-               .AddTextBox(XO("(s&emitones) [-12 to 12]:"), wxT(""), 12);
+               .AddTextBox(XXO("(s&emitones) [-12 to 12]:"), wxT(""), 12);
 
             m_pTextCtrl_PitchPercentChangeEnd = S.Id(ID_PitchPercentChangeEnd)
                .Validator<FloatingPointValidator<double>>(
                   3, &m_PitchPercentChangeEnd,
                   NumValidatorStyle::NO_TRAILING_ZEROES,
                   MIN_PitchPercentStart, MAX_PitchPercentStart)
-               .AddTextBox(XO("(%) [-50 to 100]:"), wxT(""), 12);
+               .AddTextBox(XXO("(%) [-50 to 100]:"), wxT(""), 12);
          }
          S.EndMultiColumn();
       }
