@@ -27,6 +27,8 @@
 #include "../../Audacity.h" // for USE_* macros
 #include "VSTEffect.h"
 
+#include "../../widgets/ProgressDialog.h"
+
 #if 0
 #if defined(BUILDING_AUDACITY)
 #include "../../PlatformCompatibility.h"
@@ -58,7 +60,6 @@
 #include <wx/log.h>
 #include <wx/module.h>
 #include <wx/process.h>
-#include <wx/progdlg.h>
 #include <wx/recguard.h>
 #include <wx/sizer.h>
 #include <wx/slider.h>
@@ -142,7 +143,7 @@ DECLARE_MODULE_ENTRY(AudacityModule)
 {
    // Create our effects module and register
    // Trust the module manager not to leak this
-   return safenew VSTEffectsModule(moduleManager, path);
+   return safenew VSTEffectsModule(path);
 }
 
 // ============================================================================
@@ -305,10 +306,8 @@ public:
 // VSTEffectsModule
 //
 // ============================================================================
-VSTEffectsModule::VSTEffectsModule(ModuleManagerInterface *moduleManager,
-                                   const wxString *path)
+VSTEffectsModule::VSTEffectsModule(const wxString *path)
 {
-   mModMan = moduleManager;
    if (path)
    {
       mPath = *path;
@@ -517,7 +516,7 @@ unsigned VSTEffectsModule::DiscoverPluginsAtPath(
    wxString effectIDs = wxT("0;");
    wxStringTokenizer effectTzr(effectIDs, wxT(";"));
 
-   Optional<wxProgressDialog> progress{};
+   Optional<ProgressDialog> progress{};
    size_t idCnt = 0;
    size_t idNdx = 0;
 
@@ -541,7 +540,7 @@ unsigned VSTEffectsModule::DiscoverPluginsAtPath(
       }
       catch (...)
       {
-         wxLogMessage(_("VST plugin registration failed for %s\n"), path);
+         wxLogMessage(wxT("VST plugin registration failed for %s\n"), path);
          error = true;
       }
 
@@ -577,17 +576,18 @@ unsigned VSTEffectsModule::DiscoverPluginsAtPath(
                idCnt = effectTzr.CountTokens();
                if (idCnt > 3)
                {
-                  progress.emplace( _("Scanning Shell VST"),
-                        wxString::Format(_("Registering %d of %d: %-64.64s"), 0, idCnt,
-                                         proc.GetSymbol().Translation()),
-                        static_cast<int>(idCnt),
-                        nullptr,
-                        wxPD_APP_MODAL |
+                  progress.emplace( XO("Scanning Shell VST"),
+                        XO("Registering %d of %d: %-64.64s")
+                           .Format( 0, idCnt, proc.GetSymbol().Translation())
+                                   /*
+                        , wxPD_APP_MODAL |
                            wxPD_AUTO_HIDE |
                            wxPD_CAN_ABORT |
                            wxPD_ELAPSED_TIME |
                            wxPD_ESTIMATED_TIME |
-                           wxPD_REMAINING_TIME );
+                           wxPD_REMAINING_TIME
+                                    */
+                  );
                   progress->Show();
                }
             break;
@@ -652,9 +652,10 @@ unsigned VSTEffectsModule::DiscoverPluginsAtPath(
                if (progress)
                {
                   idNdx++;
-                  cont = progress->Update(idNdx,
-                     wxString::Format(_("Registering %d of %d: %-64.64s"), idNdx, idCnt,
-                        proc.GetSymbol().Translation() ));
+                  auto result = progress->Update((int)idNdx, (int)idCnt,
+                     XO("Registering %d of %d: %-64.64s")
+                        .Format( idNdx, idCnt, proc.GetSymbol().Translation() ));
+                  cont = (result == ProgressResult::Success);
                }
 
                if (!skip && cont)
@@ -825,7 +826,7 @@ void VSTEffectOptionsDialog::PopulateOrExchange(ShuttleGui & S)
                t = S.Validator<IntegerValidator<int>>(
                      &mBufferSize, NumValidatorStyle::DEFAULT, 8, 1048576 * 1)
                   .MinSize( { 100, -1 } )
-                  .TieNumericTextBox(XO("&Buffer Size (8 to 1048576 samples):"),
+                  .TieNumericTextBox(XXO("&Buffer Size (8 to 1048576 samples):"),
                                        mBufferSize,
                                        12);
             }
@@ -845,7 +846,7 @@ void VSTEffectOptionsDialog::PopulateOrExchange(ShuttleGui & S)
 
             S.StartHorizontalLay(wxALIGN_LEFT);
             {
-               S.TieCheckBox(XO("Enable &compensation"),
+               S.TieCheckBox(XXO("Enable &compensation"),
                              mUseLatency);
             }
             S.EndHorizontalLay();
@@ -859,7 +860,7 @@ void VSTEffectOptionsDialog::PopulateOrExchange(ShuttleGui & S)
 " A basic text-only method is also available. "
 " Reopen the effect for this to take effect."),
                false, 0, 650);
-            S.TieCheckBox(XO("Enable &graphical interface"),
+            S.TieCheckBox(XXO("Enable &graphical interface"),
                           mUseGUI);
          }
          S.EndStatic();
@@ -2173,7 +2174,7 @@ bool VSTEffect::Load()
    }
    catch (...)
    {
-      wxLogMessage(_("VST plugin initialization failed\n"));
+      wxLogMessage(wxT("VST plugin initialization failed\n"));
       mAEffect = NULL;
    }
 
