@@ -59,7 +59,7 @@ DECLARE_MODULE_ENTRY(AudacityModule)
 {
    // Create and register the importer
    // Trust the module manager not to leak this
-   return safenew LV2EffectsModule(moduleManager, path);
+   return safenew LV2EffectsModule(path);
 }
 
 // ============================================================================
@@ -76,10 +76,8 @@ using UriHash = std::unordered_map<wxString, LilvNode*>;
 
 LilvWorld *gWorld = NULL;
 
-LV2EffectsModule::LV2EffectsModule(ModuleManagerInterface *moduleManager,
-                                   const wxString *path)
+LV2EffectsModule::LV2EffectsModule(const wxString *path)
 {
-   mModMan = moduleManager;
    if (path)
    {
       mPath = *path;
