@@ -19,7 +19,6 @@
 #include <wx/button.h>
 #include <wx/cmdline.h>
 #include <wx/combobox.h>
-#include <wx/filedlg.h>
 #include <wx/log.h>
 #include <wx/process.h>
 #include <wx/sizer.h>
@@ -86,16 +85,15 @@ ExportCLOptions::ExportCLOptions(wxWindow *parent, int WXUNUSED(format))
 {
    mHistory.Load(*gPrefs, wxT("/FileFormats/ExternalProgramHistory"));
 
-   if (mHistory.GetCount() == 0) {
-      mHistory.AddFileToHistory(wxT("ffmpeg -i - \"%f.opus\""), false);
-      mHistory.AddFileToHistory(wxT("ffmpeg -i - \"%f.wav\""), false);
-      mHistory.AddFileToHistory(wxT("ffmpeg -i - \"%f\""), false);
-      mHistory.AddFileToHistory(wxT("lame - \"%f\""), false);
+   if (mHistory.empty()) {
+      mHistory.Append(wxT("ffmpeg -i - \"%f.opus\""));
+      mHistory.Append(wxT("ffmpeg -i - \"%f.wav\""));
+      mHistory.Append(wxT("ffmpeg -i - \"%f\""));
+      mHistory.Append(wxT("lame - \"%f\""));
    }
 
-   mHistory.AddFileToHistory(gPrefs->Read(wxT("/FileFormats/ExternalProgramExportCommand"),
-                                          mHistory.GetHistoryFile(0)),
-                             false);
+   mHistory.Append(gPrefs->Read(wxT("/FileFormats/ExternalProgramExportCommand"),
+                                          mHistory[ 0 ]));
 
    ShuttleGui S(this, eIsCreatingFromPrefs);
    PopulateOrExchange(S);
@@ -114,14 +112,8 @@ ExportCLOptions::~ExportCLOptions()
 ///
 void ExportCLOptions::PopulateOrExchange(ShuttleGui & S)
 {
-   wxArrayStringEx cmds;
-   wxString cmd;
-
-   for (size_t i = 0; i < mHistory.GetCount(); i++) {
-      cmd = mHistory.GetHistoryFile(i);
-      cmds.push_back(mHistory.GetHistoryFile(i));
-   }
-   cmd = cmds[0];
+   wxArrayStringEx cmds( mHistory.begin(), mHistory.end() );
+   auto cmd = cmds[0];
 
    S.StartVerticalLay();
    {
@@ -131,13 +123,13 @@ void ExportCLOptions::PopulateOrExchange(ShuttleGui & S)
          S.StartMultiColumn(3, wxEXPAND);
          {
             S.SetStretchyCol(1);
-            mCmd = S.AddCombo(XO("Command:"),
+            mCmd = S.AddCombo(XXO("Command:"),
                               cmd,
                               cmds);
-            S.Id(ID_BROWSE).AddButton(XO("Browse..."),
+            S.Id(ID_BROWSE).AddButton(XXO("Browse..."),
                                       wxALIGN_CENTER_VERTICAL);
             S.AddFixedText( {} );
-            S.TieCheckBox(XO("Show output"),
+            S.TieCheckBox(XXO("Show output"),
                           {wxT("/FileFormats/ExternalProgramShowOutput"),
                            false});
          }
@@ -172,7 +164,7 @@ bool ExportCLOptions::TransferDataFromWindow()
 
    wxString cmd = mCmd->GetValue();
 
-   mHistory.AddFileToHistory(cmd, false);
+   mHistory.Append(cmd);
    mHistory.Save(*gPrefs, wxT("/FileFormats/ExternalProgramHistory"));
 
    gPrefs->Write(wxT("/FileFormats/ExternalProgramExportCommand"), cmd);
@@ -601,7 +593,7 @@ ProgressResult ExportCL::Export(AudacityProject *project,
          .AddTextWindow(mCmd + wxT("\n\n") + output);
       S.StartHorizontalLay(wxALIGN_CENTER, false);
       {
-         S.Id(wxID_OK).AddButton(XO("&OK"), wxALIGN_CENTER, true);
+         S.Id(wxID_OK).AddButton(XXO("&OK"), wxALIGN_CENTER, true);
       }
       dlg.GetSizer()->AddSpacer(5);
       dlg.Layout();
