@@ -44,6 +44,7 @@
 #include <wx/window.h>
 #include <wx/log.h>
 #include <wx/intl.h>
+#include <wx/stream.h>
 
 #include "Export.h"
 #include "../FileIO.h"
@@ -77,10 +78,8 @@
 
 namespace {
 
-// Typo fix of kpbs to be removed after 2.4.0
 // i18n-hint kbps abbreviates "thousands of bits per second"
-inline TranslatableString n_kbps( int n ) { return 
-   ((XO("%d kpbs").Translation()=="%d kpbs")?XO("%d kbps"):XO("%d kpbs")).Format( n ); }
+inline TranslatableString n_kbps( int n ) { return XO("%d kbps").Format( n ); }
 
 const TranslatableStrings BitRateNames {
    n_kbps(16),
@@ -164,7 +163,7 @@ void ExportMP2Options::PopulateOrExchange(ShuttleGui & S)
          S.StartMultiColumn(2, wxCENTER);
          {
             S.TieNumberAsChoice(
-               XO("Bit Rate:"),
+               XXO("Bit Rate:"),
                {wxT("/FileFormats/MP2Bitrate"),
                 160},
                BitRateNames,
