@@ -11,7 +11,6 @@
 #ifndef _IMPORT_
 #define _IMPORT_
 
-#include "ImportRaw.h" // defines TrackHolders
 #include "ImportForwards.h"
 #include "audacity/Types.h"
 #include <vector>
@@ -20,7 +19,7 @@
 #include "../widgets/wxPanelWrapper.h" // to inherit
 #include "../FileNames.h" // for FileType
 
-#include "../commands/CommandManager.h" // for Registry::Placement
+#include "../Registry.h"
 
 class wxArrayString;
 class wxListBox;
@@ -34,8 +33,10 @@ class UnusableImportPlugin;
 typedef bool (*progress_callback_t)( void *userData, float percent );
 
 class ExtImportItem;
+class WaveTrack;
 
 using ExtImportItems = std::vector< std::unique_ptr<ExtImportItem> >;
+using TrackHolders = std::vector< std::vector< std::shared_ptr<WaveTrack> > >;
 
 class ExtImportItem
 {
