@@ -49,11 +49,9 @@ but little else.
 
 #include "audacity/Types.h"
 #include "../Internat.h"
-
-#include "ImportRaw.h" // defines TrackHolders
+#include "../MemoryX.h"
 
 class AudacityProject;
-class wxArrayString;
 class ProgressDialog;
 enum class ProgressResult : unsigned;
 class TrackFactory;
@@ -109,6 +107,9 @@ protected:
 };
 
 
+class WaveTrack;
+using TrackHolders = std::vector< std::vector< std::shared_ptr<WaveTrack> > >;
+
 class ImportFileHandle /* not final */
 {
 public:
