@@ -610,7 +610,7 @@ void OnPaste(const CommandContext &context)
             }
          },
          [&](LabelTrack *lt, const Track::Fallthrough &fallthrough) {
-            if (!lt->GetSelected())
+            if (!lt->GetSelected() && !lt->IsSyncLockSelected())
                return fallthrough();
 
             lt->Clear(t0, t1);
@@ -747,7 +747,8 @@ void OnSilence(const CommandContext &context)
    ProjectHistory::Get( project ).PushState(
       XO("Silenced selected tracks for %.2f seconds at %.2f")
          .Format( selectedRegion.duration(), selectedRegion.t0() ),
-      XO("Silence"));
+      /* i18n-hint: verb */
+      XC("Silence", "command"));
 }
 
 void OnTrim(const CommandContext &context)
@@ -1053,7 +1054,7 @@ BaseItemSharedPtr EditMenu()
 
    static BaseItemSharedPtr menu{
    ( FinderScope{ findCommandHandler },
-   Menu( wxT("Edit"), XO("&Edit"),
+   Menu( wxT("Edit"), XXO("&Edit"),
       Section( "UndoRedo",
          Command( wxT("Undo"), XXO("&Undo"), FN(OnUndo),
             AudioIONotBusyFlag() | UndoAvailableFlag(), wxT("Ctrl+Z") ),
@@ -1088,7 +1089,7 @@ BaseItemSharedPtr EditMenu()
             NotBusyTimeAndTracksFlags, wxT("Ctrl+D") ),
 
          Section( "",
-            Menu( wxT("RemoveSpecial"), XO("R&emove Special"),
+            Menu( wxT("RemoveSpecial"), XXO("R&emove Special"),
                Section( "",
                   /* i18n-hint: (verb) Do a special kind of cut*/
                   Command( wxT("SplitCut"), XXO("Spl&it Cut"), FN(OnSplitCut),
@@ -1118,7 +1119,7 @@ BaseItemSharedPtr EditMenu()
       Section( "Other",
       //////////////////////////////////////////////////////////////////////////
 
-         Menu( wxT("Clip"), XO("Clip B&oundaries"),
+         Menu( wxT("Clip"), XXO("Clip B&oundaries"),
             Section( "",
                /* i18n-hint: (verb) It's an item on a menu. */
                Command( wxT("Split"), XXO("Sp&lit"), FN(OnSplit),
@@ -1173,7 +1174,7 @@ BaseItemSharedPtr ExtraEditMenu()
       AudioIONotBusyFlag() | TracksSelectedFlag() | TimeSelectedFlag();
    static BaseItemSharedPtr menu{
    ( FinderScope{ findCommandHandler },
-   Menu( wxT("Edit"), XO("&Edit"),
+   Menu( wxT("Edit"), XXO("&Edit"),
       Command( wxT("DeleteKey"), XXO("&Delete Key"), FN(OnDelete),
          (flags | NoAutoSelect()),
          wxT("Backspace") ),
