@@ -11,6 +11,8 @@
 #include "../Project.h"
 #include "../ProjectSettings.h"
 #include "../ProjectWindow.h"
+#include "../ProjectSelectionManager.h"
+#include "../toolbars/ToolManager.h"
 #include "../Screenshot.h"
 #include "../commands/CommandContext.h"
 #include "../commands/CommandManager.h"
@@ -19,6 +21,7 @@
 #include "../effects/EffectUI.h"
 #include "../effects/RealtimeEffectManager.h"
 #include "../prefs/EffectsPrefs.h"
+#include "../prefs/PrefsDialog.h"
 
 // private helper classes and functions
 namespace {
@@ -41,121 +44,90 @@ void DoManagePluginsMenu(AudacityProject &project, EffectType type)
 
 bool CompareEffectsByName(const PluginDescriptor *a, const PluginDescriptor *b)
 {
-   auto akey = a->GetSymbol().Translation();
-   auto bkey = b->GetSymbol().Translation();
-
-   akey += a->GetPath();
-   bkey += b->GetPath();
-
-   return akey.CmpNoCase(bkey) < 0;
+   return
+      std::make_pair( a->GetSymbol().Translation(), a->GetPath() ) <
+      std::make_pair( b->GetSymbol().Translation(), b->GetPath() );
 }
 
 bool CompareEffectsByPublisher(
    const PluginDescriptor *a, const PluginDescriptor *b)
 {
    auto &em = EffectManager::Get();
-   auto akey = em.GetVendorName(a->GetID()).Translation();
-   auto bkey = em.GetVendorName(b->GetID()).Translation();
+   
+   auto akey = em.GetVendorName(a->GetID());
+   auto bkey = em.GetVendorName(b->GetID());
 
    if (akey.empty())
-   {
-      akey = _("Uncategorized");
-   }
+      akey = XO("Uncategorized");
    if (bkey.empty())
-   {
-      bkey = _("Uncategorized");
-   }
+      bkey = XO("Uncategorized");
 
-   akey += a->GetSymbol().Translation();
-   bkey += b->GetSymbol().Translation();
-
-   akey += a->GetPath();
-   bkey += b->GetPath();
-
-   return akey.CmpNoCase(bkey) < 0;
+   return
+      std::make_tuple(
+         akey.Translation(), a->GetSymbol().Translation(), a->GetPath() ) <
+      std::make_tuple(
+         bkey.Translation(), b->GetSymbol().Translation(), b->GetPath() );
 }
 
 bool CompareEffectsByPublisherAndName(
    const PluginDescriptor *a, const PluginDescriptor *b)
 {
    auto &em = EffectManager::Get();
-   auto akey = em.GetVendorName(a->GetID()).Translation();
-   auto bkey = em.GetVendorName(b->GetID()).Translation();
+   auto akey = em.GetVendorName(a->GetID());
+   auto bkey = em.GetVendorName(b->GetID());
 
    if (a->IsEffectDefault())
-   {
-      akey = wxEmptyString;
-   }
+      akey = {};
    if (b->IsEffectDefault())
-   {
-      bkey = wxEmptyString;
-   }
+      bkey = {};
 
-   akey += a->GetSymbol().Translation();
-   bkey += b->GetSymbol().Translation();
-
-   akey += a->GetPath();
-   bkey += b->GetPath();
-
-   return akey.CmpNoCase(bkey) < 0;
+   return
+      std::make_tuple(
+         akey.Translation(), a->GetSymbol().Translation(), a->GetPath() ) <
+      std::make_tuple(
+         bkey.Translation(), b->GetSymbol().Translation(), b->GetPath() );
 }
 
 bool CompareEffectsByTypeAndName(
    const PluginDescriptor *a, const PluginDescriptor *b)
 {
    auto &em = EffectManager::Get();
-   auto akey = em.GetEffectFamilyName(a->GetID()).Translation();
-   auto bkey = em.GetEffectFamilyName(b->GetID()).Translation();
+   auto akey = em.GetEffectFamilyName(a->GetID());
+   auto bkey = em.GetEffectFamilyName(b->GetID());
 
    if (akey.empty())
-   {
-      akey = _("Uncategorized");
-   }
+      akey = XO("Uncategorized");
    if (bkey.empty())
-   {
-      bkey = _("Uncategorized");
-   }
+      bkey = XO("Uncategorized");
 
    if (a->IsEffectDefault())
-   {
-      akey = wxEmptyString;
-   }
+      akey = {};
    if (b->IsEffectDefault())
-   {
-      bkey = wxEmptyString;
-   }
+      bkey = {};
 
-   akey += a->GetSymbol().Translation();
-   bkey += b->GetSymbol().Translation();
-
-   akey += a->GetPath();
-   bkey += b->GetPath();
-
-   return akey.CmpNoCase(bkey) < 0;
+   return
+      std::make_tuple(
+         akey.Translation(), a->GetSymbol().Translation(), a->GetPath() ) <
+      std::make_tuple(
+         bkey.Translation(), b->GetSymbol().Translation(), b->GetPath() );
 }
 
 bool CompareEffectsByType(const PluginDescriptor *a, const PluginDescriptor *b)
 {
    auto &em = EffectManager::Get();
-   auto akey = em.GetEffectFamilyName(a->GetID()).Translation();
-   auto bkey = em.GetEffectFamilyName(b->GetID()).Translation();
+   auto akey = em.GetEffectFamilyName(a->GetID());
+   auto bkey = em.GetEffectFamilyName(b->GetID());
 
    if (akey.empty())
-   {
-      akey = _("Uncategorized");
-   }
+      akey = XO("Uncategorized");
    if (bkey.empty())
-   {
-      bkey = _("Uncategorized");
-   }
+      bkey = XO("Uncategorized");
 
-   akey += a->GetSymbol().Translation();
-   bkey += b->GetSymbol().Translation();
-
-   akey += a->GetPath();
-   bkey += b->GetPath();
-
-   return akey.CmpNoCase(bkey) < 0;
+   return
+      std::make_tuple(
+         akey.Translation(), a->GetSymbol().Translation(), a->GetPath() ) <
+      std::make_tuple(
+         bkey.Translation(), b->GetSymbol().Translation(), b->GetPath() );
 }
 
 // Forward-declared function has its definition below with OnEffect in view
@@ -400,6 +372,46 @@ namespace PluginActions {
 
 struct Handler : CommandHandlerObject {
 
+void OnResetConfig(const CommandContext &context)
+{
+   auto &project = context.project;
+   //wxString dir = gPrefs->Read("/Directories/TempDir");
+   gPrefs->DeleteAll();
+
+   // Directory will be reset on next restart.
+   wxString dir = FileNames::DefaultTempDir();
+   gPrefs->Write("/Directories/TempDir", dir);
+   gPrefs->Write("/GUI/SyncLockTracks", 0);
+   gPrefs->Write("/SnapTo", 0 );
+   ProjectSelectionManager::Get( project ).AS_SetSnapTo( 0 );
+   // There are many more things we could reset here.
+   // Beeds discussion as to which make sense to.
+   // Maybe in future versions?
+   // - Reset Effects
+   // - Reset Recording and Playback volumes
+   // - Reset Selection formats (and for spectral too)
+   // - Reset Play-at-speed speed to x1
+   // - Stop playback/recording and unapply pause.
+   // - Set Zoom sensibly.
+   //ProjectSelectionManager::Get(project).AS_SetRate(44100.0);
+   gPrefs->Write("/AudioIO/SoundActivatedRecord", 0);
+   gPrefs->Flush();
+   DoReloadPreferences(project);
+   ToolManager::OnResetToolBars(context);
+
+   // These are necessary to preserve the newly correctly laid out toolbars.
+   // In particular the Device Toolbar ends up short on next restart, 
+   // if they are left out.
+   gPrefs->Write(wxT("/PrefsVersion"), wxString(wxT(AUDACITY_PREFS_VERSION_STRING)));
+   // write out the version numbers to the prefs file for future checking
+   gPrefs->Write(wxT("/Version/Major"), AUDACITY_VERSION);
+   gPrefs->Write(wxT("/Version/Minor"), AUDACITY_RELEASE);
+   gPrefs->Write(wxT("/Version/Micro"), AUDACITY_REVISION);
+
+   gPrefs->Flush();
+
+}
+
 void OnManageGenerators(const CommandContext &context)
 {
    auto &project = context.project;
@@ -568,6 +580,7 @@ void AddEffectMenuItemGroup(
    int groupCnt = namesCnt;
    for (int i = 0; i < namesCnt; i++)
    {
+      // compare full translations not msgids!
       while (i + 1 < namesCnt && names[i].Translation() == names[i + 1].Translation())
       {
          i++;
@@ -604,12 +617,14 @@ void AddEffectMenuItemGroup(
          pTable = &temp1;
       }
 
+      // compare full translations not msgids!
       if (i + 1 < namesCnt && names[i].Translation() == names[i + 1].Translation())
       {
          // collect a sub-menu for like-named items
          const auto name = names[i];
          const auto translation = name.Translation();
          BaseItemPtrs temp2;
+         // compare full translations not msgids!
          while (i < namesCnt && names[i].Translation() == translation)
          {
             const PluginDescriptor *plug =
@@ -663,7 +678,7 @@ void AddEffectMenuItemGroup(
             }
             // Done collecting
             table.push_back( Menu( wxEmptyString,
-               XO("Plug-in %d to %d").Format( groupNdx + 1, end ),
+               XXO("Plug-in %d to %d").Format( groupNdx + 1, end ),
                std::move( temp1 )
             ) );
             items = max;
@@ -711,7 +726,7 @@ BaseItemSharedPtr GenerateMenu()
 
    static BaseItemSharedPtr menu{
    ( FinderScope{ findCommandHandler },
-   Menu( wxT("Generate"), XO("&Generate"),
+   Menu( wxT("Generate"), XXO("&Generate"),
 #ifdef EXPERIMENTAL_EFFECT_MANAGEMENT
       Section( "Manage",
          Command( wxT("ManageGenerators"), XXO("Add / Remove Plug-ins..."),
@@ -751,7 +766,7 @@ BaseItemSharedPtr EffectMenu()
 
    static BaseItemSharedPtr menu{
    ( FinderScope{ findCommandHandler },
-   Menu( wxT("Effect"), XO("Effe&ct"),
+   Menu( wxT("Effect"), XXO("Effe&ct"),
 #ifdef EXPERIMENTAL_EFFECT_MANAGEMENT
       Section( "Manage",
          Command( wxT("ManageEffects"), XXO("Add / Remove Plug-ins..."),
@@ -804,7 +819,7 @@ BaseItemSharedPtr AnalyzeMenu()
 
    static BaseItemSharedPtr menu{
    ( FinderScope{ findCommandHandler },
-   Menu( wxT("Analyze"), XO("&Analyze"),
+   Menu( wxT("Analyze"), XXO("&Analyze"),
 #ifdef EXPERIMENTAL_EFFECT_MANAGEMENT
       Section( "Manage",
          Command( wxT("ManageAnalyzers"), XXO("Add / Remove Plug-ins..."),
@@ -838,7 +853,7 @@ BaseItemSharedPtr ToolsMenu()
 
    static BaseItemSharedPtr menu{
    ( FinderScope{ findCommandHandler },
-   Menu( wxT("Tools"), XO("T&ools"),
+   Menu( wxT("Tools"), XXO("T&ools"),
       Section( "Manage",
    #ifdef EXPERIMENTAL_EFFECT_MANAGEMENT
          Command( wxT("ManageTools"), XXO("Add / Remove Plug-ins..."),
@@ -851,7 +866,7 @@ BaseItemSharedPtr ToolsMenu()
          Command( wxT("ManageMacros"), XXO("&Macros..."),
             FN(OnManageMacros), AudioIONotBusyFlag() ),
 
-         Menu( wxT("Macros"), XO("&Apply Macro"),
+         Menu( wxT("Macros"), XXO("&Apply Macro"),
             // Palette has no access key to ensure first letter navigation of
             // sub menu
             Section( "",
@@ -868,6 +883,10 @@ BaseItemSharedPtr ToolsMenu()
       ),
 
       Section( "Other",
+         Command( wxT("ConfigReset"), XXO("Reset &Configuration"),
+            FN(OnResetConfig),
+            AudioIONotBusyFlag() ),
+
          Command( wxT("FancyScreenshot"), XXO("&Screenshot..."),
             FN(OnScreenshot), AudioIONotBusyFlag() ),
 
@@ -925,7 +944,7 @@ BaseItemSharedPtr ExtraScriptablesIMenu()
    static BaseItemSharedPtr menu{
    ( FinderScope{ findCommandHandler },
    // i18n-hint: Scriptables are commands normally used from Python, Perl etc.
-   Menu( wxT("Scriptables1"), XO("Script&ables I"),
+   Menu( wxT("Scriptables1"), XXO("Script&ables I"),
       // Note that the PLUGIN_SYMBOL must have a space between words,
       // whereas the short-form used here must not.
       // (So if you did write "CompareAudio" for the PLUGIN_SYMBOL name, then
@@ -977,7 +996,7 @@ BaseItemSharedPtr ExtraScriptablesIIMenu()
    static BaseItemSharedPtr menu{
    ( FinderScope{ findCommandHandler },
    // i18n-hint: Scriptables are commands normally used from Python, Perl etc.
-   Menu( wxT("Scriptables2"), XO("Scripta&bles II"),
+   Menu( wxT("Scriptables2"), XXO("Scripta&bles II"),
       Command( wxT("Select"), XXO("Select..."), FN(OnAudacityCommand),
          AudioIONotBusyFlag() ),
       Command( wxT("SetTrack"), XXO("Set Track..."), FN(OnAudacityCommand),
