@@ -72,7 +72,7 @@ void BatchPrefs::PopulateOrExchange( ShuttleGui & S )
    S.StartStatic( XO("Behaviors"),1 );
    {
 #ifdef _DEBUG
-      S.TieCheckBox( XO("&Don't apply effects in batch mode"),
+      S.TieCheckBox( XXO("&Don't apply effects in batch mode"),
          {wxT("/Batch/Debug"), false});
 #endif
    }
