@@ -62,7 +62,6 @@ void ModulePrefs::GetAllModuleStatuses(){
    // Modules could for example be:
    //    mod-script-pipe
    //    mod-nyq-bench
-   //    mod-track-panel
    //    mod-menu-munger
    //    mod-theming
 
@@ -166,26 +165,63 @@ bool ModulePrefs::Commit()
 
 
 // static function that tells us about a module.
-int ModulePrefs::GetModuleStatus(const FilePath &fname){
+int ModulePrefs::GetModuleStatus(const FilePath &fname)
+{
    // Default status is NEW module, and we will ask once.
    int iStatus = kModuleNew;
 
-   wxString ShortName = wxFileName( fname ).GetName();
-   wxString PrefName = wxString( wxT("/Module/") ) + ShortName.Lower();
+   wxFileName FileName( fname );
+   wxString ShortName = FileName.GetName().Lower();
+
+   wxString PathPref = wxString( wxT("/ModulePath/") ) + ShortName;
+   wxString StatusPref = wxString( wxT("/Module/") ) + ShortName;
+   wxString DateTimePref = wxString( wxT("/ModuleDateTime/") ) + ShortName;
+
+   wxString ModulePath = gPrefs->Read( PathPref, wxEmptyString );
+   if( ModulePath.IsSameAs( fname ) )
+   {
+      gPrefs->Read( StatusPref, &iStatus, kModuleNew );
+
+      wxDateTime DateTime = FileName.GetModificationTime();
+      wxDateTime OldDateTime;
+      OldDateTime.ParseISOCombined( gPrefs->Read( DateTimePref, wxEmptyString ) );
+
+      // Some platforms return milliseconds, some do not...level the playing field
+      DateTime.SetMillisecond( 0 );
+      OldDateTime.SetMillisecond( 0 );
+
+      // fix up a bad status or reset for newer module
+      if( iStatus > kModuleNew || !OldDateTime.IsEqualTo( DateTime ) )
+      {
+         iStatus=kModuleNew;
+      }
+   }
+   else
+   {
+      // Remove previously saved since it's no longer valid
+      gPrefs->DeleteEntry( PathPref );
+      gPrefs->DeleteEntry( StatusPref );
+      gPrefs->DeleteEntry( DateTimePref );
+   }
 
-   gPrefs->Read( PrefName, &iStatus, kModuleNew );
-   // fix up a bad status.
-   if( iStatus > kModuleNew )
-      iStatus=kModuleNew;
    return iStatus;
 }
 
-void ModulePrefs::SetModuleStatus(const FilePath &fname, int iStatus){
-   wxString ShortName = wxFileName( fname ).GetName();
-   wxString PrefName = wxString( wxT("/Module/") ) + ShortName.Lower();
+void ModulePrefs::SetModuleStatus(const FilePath &fname, int iStatus)
+{
+   wxFileName FileName( fname );
+   wxDateTime DateTime = FileName.GetModificationTime();
+   wxString ShortName = FileName.GetName().Lower();
+
+   wxString PrefName = wxString( wxT("/Module/") ) + ShortName;
    gPrefs->Write( PrefName, iStatus );
-   PrefName = wxString( wxT("/ModulePath/") ) + ShortName.Lower();
+
+   PrefName = wxString( wxT("/ModulePath/") ) + ShortName;
    gPrefs->Write( PrefName, fname );
+
+   PrefName = wxString( wxT("/ModuleDateTime/") ) + ShortName;
+   gPrefs->Write( PrefName, DateTime.FormatISOCombined() );
+
    gPrefs->Flush();
 }
 
