@@ -17,8 +17,6 @@
 #include "../Audacity.h" // for USE_* macros
 #include "PrefsDialog.h"
 
-#include <mutex> // for std::call_once
-
 #include <wx/app.h>
 #include <wx/setup.h> // for wxUSE_* macros
 #include <wx/defs.h>
@@ -370,14 +368,6 @@ wxAccStatus TreeCtrlAx::Select(int childId, wxAccSelectionFlags selectFlags)
 #endif
 
 
-// PrefsPanel might move out into its own file in due ocurse.
-PluginPath PrefsPanel::GetPath(){      return BUILTIN_PREFS_PANEL_PREFIX + GetSymbol().Internal(); }
-VendorSymbol PrefsPanel::GetVendor(){  return XO("Audacity");}
-wxString PrefsPanel::GetVersion(){     return AUDACITY_VERSION_STRING;}
-
-
-
-
 BEGIN_EVENT_TABLE(PrefsDialog, wxDialogWrapper)
    EVT_BUTTON(wxID_OK, PrefsDialog::OnOK)
    EVT_BUTTON(wxID_CANCEL, PrefsDialog::OnCancel)
@@ -452,110 +442,10 @@ int wxTreebookExt::SetSelection(size_t n)
    return i;
 }
 
-namespace {
-
-struct PrefsItem final : Registry::ConcreteGroupItem<false> {
-   PrefsPanel::Factory factory;
-   bool expanded{ false };
-
-   PrefsItem( const wxString &name,
-      const PrefsPanel::Factory &factory_, bool expanded_ )
-         : ConcreteGroupItem<false>{ name }
-         , factory{ factory_ }, expanded{ expanded_ }
-   {}
-};
-
-// Collects registry tree nodes into a vector, in preorder.
-struct PrefsItemVisitor final : Registry::Visitor {
-   PrefsItemVisitor( PrefsDialog::Factories &factories_ )
-      : factories{ factories_ }
-   {
-      childCounts.push_back( 0 );
-   }
-   void BeginGroup( Registry::GroupItem &item, const Path & ) override
-   {
-      auto pItem = dynamic_cast<PrefsItem*>( &item );
-      if (!pItem)
-         return;
-      indices.push_back( factories.size() );
-      factories.emplace_back( pItem->factory, 0, pItem->expanded );
-      ++childCounts.back();
-      childCounts.push_back( 0 );
-   }
-   void EndGroup( Registry::GroupItem &item, const Path & ) override
-   {
-      auto pItem = dynamic_cast<PrefsItem*>( &item );
-      if (!pItem)
-         return;
-      auto &factory = factories[ indices.back() ];
-      factory.nChildren = childCounts.back();
-      childCounts.pop_back();
-      indices.pop_back();
-   }
-
-   PrefsDialog::Factories &factories;
-   std::vector<size_t> childCounts;
-   std::vector<size_t> indices;
-};
-
-
-const auto PathStart = wxT("Preferences");
-   
-}
-
-
-namespace {
-static Registry::GroupItem &sRegistry()
-{
-   static Registry::TransparentGroupItem<> registry{ PathStart };
-   return registry;
-}
-}
-
-PrefsPanel::Registration::Registration( const wxString &name,
-   const Factory &factory, bool expanded,
-   const Registry::Placement &placement )
-{
-   Registry::RegisterItem( sRegistry(), placement,
-      std::make_unique< PrefsItem >( name, factory, expanded ) );
-}
-
-PrefsDialog::Factories
-&PrefsDialog::DefaultFactories()
-{
-   // Once only, cause initial population of preferences for the ordering
-   // of some preference pages that used to be given in a table but are now
-   // separately registered in several .cpp files; the sequence of registration
-   // depends on unspecified accidents of static initialization order across
-   // compilation units, so we need something specific here to preserve old
-   // default appearance of the preference dialog.
-   // But this needs only to mention some strings -- there is no compilation or
-   // link dependency of this source file on those other implementation files.
-   static Registry::OrderingPreferenceInitializer init{
-      PathStart,
-      {
-         {wxT(""),
-       wxT("Device,Playback,Recording,Quality,GUI,Tracks,ImportExport,Directories,Warnings,Effects,KeyConfig,Mouse")
-         },
-         {wxT("/Tracks"), wxT("TracksBehaviors,Spectrum")},
-      }
-   };
-
-   static Factories factories;
-   static std::once_flag flag;
-
-   std::call_once( flag, []{
-      PrefsItemVisitor visitor{ factories };
-      Registry::TransparentGroupItem<> top{ PathStart };
-      Registry::Visit( visitor, &top, &sRegistry() );
-   } );
-   return factories;
-}
-
-
 PrefsDialog::PrefsDialog(
    wxWindow * parent, AudacityProject *pProject,
-   const TranslatableString &titlePrefix, Factories &factories)
+   const TranslatableString &titlePrefix,
+   PrefsPanel::Factories &factories)
 :  wxDialogWrapper(parent, wxID_ANY, XO("Audacity Preferences"),
             wxDefaultPosition,
             wxDefaultSize,
@@ -591,11 +481,11 @@ PrefsDialog::PrefsDialog(
                typedef std::pair<int, int> IntPair;
                std::vector<IntPair> stack;
                int iPage = 0;
-               for (Factories::const_iterator it = factories.begin(), end = factories.end();
+               for (auto it = factories.begin(), end = factories.end();
                   it != end; ++it, ++iPage)
                {
-                  const PrefsNode &node = *it;
-                  const PrefsPanel::Factory &factory = node.factory;
+                  const auto &node = *it;
+                  const auto &factory = node.factory;
                   wxWindow *const w = factory(mCategories, wxID_ANY, pProject);
                   if (stack.empty())
                      // Parameters are: AddPage(page, name, IsSelected, imageId).
@@ -622,8 +512,8 @@ PrefsDialog::PrefsDialog(
          // And then hiding the treebook.
 
          // Unique page, don't show the factory
-         const PrefsNode &node = factories[0];
-         const PrefsPanel::Factory &factory = node.factory;
+         const auto &node = factories[0];
+         const auto &factory = node.factory;
          mUniquePage = factory(S.GetParent(), wxID_ANY, pProject);
          wxWindow * uniquePageWindow = S.Prop(1)
             .Position(wxEXPAND)
@@ -663,7 +553,7 @@ PrefsDialog::PrefsDialog(
    if (mCategories)
    {
       int iPage = 0;
-      for (Factories::const_iterator it = factories.begin(), end = factories.end();
+      for (auto it = factories.begin(), end = factories.end();
          it != end; ++it, ++iPage)
          mCategories->ExpandNode(iPage, it->expanded);
    }
@@ -907,7 +797,8 @@ int PrefsDialog::GetSelectedPage() const
 }
 
 GlobalPrefsDialog::GlobalPrefsDialog(
-   wxWindow * parent, AudacityProject *pProject, Factories &factories)
+   wxWindow * parent, AudacityProject *pProject,
+   PrefsPanel::Factories &factories)
    : PrefsDialog(parent, pProject, XO("Preferences:"), factories)
 {
 }
@@ -934,7 +825,7 @@ void PrefsDialog::RecordExpansionState()
    if (mCategories)
    {
       int iPage = 0;
-      for (Factories::iterator it = mFactories.begin(), end = mFactories.end();
+      for (auto it = mFactories.begin(), end = mFactories.end();
          it != end; ++it, ++iPage)
          it->expanded = mCategories->IsNodeExpanded(iPage);
    }
@@ -942,30 +833,14 @@ void PrefsDialog::RecordExpansionState()
       mFactories[0].expanded = true;
 }
 
-PrefsPanel::~PrefsPanel()
-{
-}
-
-void PrefsPanel::Cancel()
-{
-}
-
-bool PrefsPanel::ShowsPreviewButton()
-{
-   return false;
-}
-
-wxString PrefsPanel::HelpPageName()
-{
-   return wxEmptyString;
-}
-
 #include <wx/frame.h>
 #include "../Menus.h"
 #include "../Project.h"
 
 void DoReloadPreferences( AudacityProject &project )
 {
+   PreferenceInitializer::ReinitializeAll();
+
    {
       GlobalPrefsDialog dialog(
          &GetProjectFrame( project ) /* parent */, &project );
