@@ -32,6 +32,7 @@ around to NEW positions.
 #include "../AColor.h"
 #include "../AllThemeResources.h"
 #include "../Internat.h"
+#include "../Theme.h"
 
 ////////////////////////////////////////////////////////////
 /// Methods for Grabber
@@ -269,7 +270,7 @@ void Grabber::OnKeyDown(wxKeyEvent &event)
 }
 
 // Piggy back in same source file as Grabber.
-// Audcaity Flicker-free StaticBitmap.
+// Audacity Flicker-free StaticBitmap.
 BEGIN_EVENT_TABLE(AStaticBitmap,wxStaticBitmap)
     EVT_ERASE_BACKGROUND(AStaticBitmap::OnErase)
 END_EVENT_TABLE()
