@@ -146,7 +146,7 @@ BEGIN_EVENT_TABLE(KeyView, wxVListBox)
    EVT_SCROLLWIN(KeyView::OnScroll)
 END_EVENT_TABLE();
 
-wxString    KeyView::CommandTranslated="Command";
+static wxString CommandTranslated = "Command";
 
 
 // ============================================================================
@@ -634,7 +634,7 @@ KeyView::UpdateHScroll()
 //
 void
 KeyView::RefreshBindings(const CommandIDs & names,
-                         const wxArrayString & categories,
+                         const TranslatableStrings & categories,
                          const TranslatableStrings & prefixes,
                          const TranslatableStrings & labels,
                          const std::vector<NormalizedKeyString> & keys,
@@ -656,6 +656,9 @@ KeyView::RefreshBindings(const CommandIDs & names,
    bool incat = false;
    bool inpfx = false;
 
+   // lookup translation once only
+   CommandTranslated = _("Command");
+
    // Examine all names...all arrays passed have the same indexes
    int cnt = (int) names.size();
    for (int i = 0; i < cnt; i++)
@@ -664,11 +667,11 @@ KeyView::RefreshBindings(const CommandIDs & names,
       int x, y;
 
       // Remove any menu code from the category and prefix
-      wxString cat = wxMenuItem::GetLabelText(categories[i]);
-      wxString pfx = wxMenuItem::GetLabelText(prefixes[i].Translation());
+      wxString cat = categories[i].Translation();
+      wxString pfx = prefixes[i].Translation();
 
       // Append "Menu" this node is for a menu title
-      if (cat != wxT("Command"))
+      if (cat != CommandTranslated)
       {
          cat.Append(wxT(" "));
          cat += _("Menu");
