@@ -53,7 +53,7 @@ END_EVENT_TABLE()
 
 const TranslatableString &DefaultWarningFooter()
 {
-   static auto result = XO("Don't show this warning again");
+   static auto result = XXO("Don't show this warning again");
    return result;
 }
 
@@ -80,7 +80,8 @@ WarningDialog::WarningDialog(wxWindow *parent, const TranslatableString &message
    S.SetBorder(0);
    S.AddStandardButtons(showCancelButton ? eOkButton | eCancelButton : eOkButton);
 
-   Fit();
+   Layout();
+   GetSizer()->Fit(this);
    CentreOnParent();
 }
 
