@@ -157,7 +157,7 @@ public:
    }
 };
 
-#include "../lib-src/FileDialog/FileDialog.h"
+#include "FileDialog/FileDialog.h"
 #include "../FileNames.h" // for FileTypes
 
 class AUDACITY_DLL_API FileDialogWrapper
